---
name: Bug report
about: Create a report to help us improve CAREamics
title: "[BUG]"
labels: bug
assignees: ''
---

## Describe the bug
<!-- A clear and concise description of what the bug is. -->

[description here]

## To Reproduce

Code snippet allowing reproducing the behaviour:
```python
# [code here]

```

Error message:
``` python
# [copy your error message here]
```

<!-- If applicable, add screenshots to help explain your problem. -->

## System
<!-- Please fill in the following information, you can check the package versions using `conda list` -->
> [!IMPORTANT]
> - OS: [e.g. iOS]
> - Python version [e.g. 3.9]
> - PyTorch version [e.g. 2.3]
> - PyTorch lightning version [e.g. 2.4]
> - CAREamics version [e.g. 0.0.4]

### Environment
<!-- Please copy here the content of your environment, you can use `conda env export > environment.yml` in unix-style command. -->

```yaml
# [your environment here]
```


## Additional context

<!-- Add any other context about the problem here. -->

[additional context here (if applicable)]
